==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ast.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contautos",
    "Address book name" : "Nome de la Llibreta de direiciones",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imaxe escoyida ye demasiáu grande (máximu 1 MB)",
    "No contacts in here" : "Nun hai nengún contactu equí",
    "Name" : "Nome",
    "Organization" : "Organización",
    "Title" : "Títulu",
    "Add field ..." : "Amestar campu ...",
    "+ New contact" : "+ Nuevu contautu",
    "No search result for {query}" : "Nengun resultáu pa la gueta {query}",
    "_%n contact_::_%n contacts_" : ["%n contautu","%n contautos"],
    "Post office box" : "Apartáu de correos",
    "Postal code" : "Códigu postal",
    "City" : "Ciudá",
    "State or province" : "Estáu o provincia",
    "Country" : "País",
    "Address" : "Direición",
    "(new group)" : "(nuevu grupu)",
    "Last name" : "Apellíu",
    "First name" : "Nome",
    "Additional names" : "Nomes adicionales",
    "Prefix" : "Prefixu",
    "Suffix" : "Sufixu",
    "All contacts" : "Tolos contautos",
    "Not grouped" : "Non agrupáu",
    "New contact" : "Contautu nuevu",
    "{addressbook} shared by {owner}" : "{addressbook} compartíu por {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nengúncontactu nel ficheru. Namás s'almiten ficheros vCard.",
    "Nickname" : "Nomatu",
    "Detailed name" : "Nome detalláu",
    "Notes" : "Notes",
    "Website" : "Sitiu web",
    "Federated Cloud ID" : "ID Ñube Federada",
    "Home" : "Casa",
    "Work" : "Trabayu",
    "Other" : "Otru",
    "Groups" : "Grupos",
    "Birthday" : "Data de nacencia",
    "Anniversary" : "Aniversariu",
    "Date of death" : "Fecha de muerte",
    "Email" : "Corréu-e",
    "Instant messaging" : "Mensaxería nel intre",
    "Phone" : "Teléfonu",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax del trabayu",
    "Pager" : "Llocalizador",
    "Voice" : "Voz",
    "Social network" : "Rede social",
    "Settings" : "Axustes"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ast.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contautos",
    "Download" : "Baxar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "Delete" : "Desaniciar",
    "can edit" : "pue editar",
    "Address book name" : "Nome de la Llibreta de direiciones",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imaxe escoyida ye demasiáu grande (máximu 1 MB)",
    "No contacts in here" : "Nun hai nengún contactu equí",
    "Name" : "Nome",
    "Organization" : "Organización",
    "Title" : "Títulu",
    "Add field ..." : "Amestar campu ...",
    "No search result for {query}" : "Nengun resultáu pa la gueta {query}",
    "_%n contact_::_%n contacts_" : ["%n contautu","%n contautos"],
    "Post office box" : "Apartáu de correos",
    "Postal code" : "Códigu postal",
    "City" : "Ciudá",
    "State or province" : "Estáu o provincia",
    "Country" : "País",
    "Address" : "Direición",
    "(new group)" : "(nuevu grupu)",
    "Last name" : "Apellíu",
    "First name" : "Nome",
    "Additional names" : "Nomes adicionales",
    "Prefix" : "Prefixu",
    "Suffix" : "Sufixu",
    "All contacts" : "Tolos contautos",
    "Not grouped" : "Non agrupáu",
    "New contact" : "Contautu nuevu",
    "{addressbook} shared by {owner}" : "{addressbook} compartíu por {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nengúncontactu nel ficheru. Namás s'almiten ficheros vCard.",
    "Nickname" : "Nomatu",
    "Detailed name" : "Nome detalláu",
    "Notes" : "Notes",
    "Website" : "Sitiu web",
    "Federated Cloud ID" : "ID Ñube Federada",
    "Home" : "Casa",
    "Work" : "Trabayu",
    "Other" : "Otru",
    "Groups" : "Grupos",
    "Birthday" : "Data de nacencia",
    "Anniversary" : "Aniversariu",
    "Date of death" : "Fecha de muerte",
    "Email" : "Corréu-e",
    "Instant messaging" : "Mensaxería nel intre",
    "Phone" : "Teléfonu",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax del trabayu",
    "Pager" : "Llocalizador",
    "Voice" : "Voz",
    "Social network" : "Rede social",
    "Settings" : "Axustes"
},
"nplurals=2; plural=(n != 1);");
